@@ -9,8 +9,8 @@
 #define AH_JOBCHANGEKEYS_L_H
 
 
-#include "aqhbci_l.h"
-#include "job_l.h"
+#include "aqhbci/aqhbci_l.h"
+#include "aqhbci/joblayer/job_l.h"
 
 
 AH_JOB *AH_Job_ChangeKeys_new(AB_PROVIDER *pro, AB_USER *u, GWEN_DB_NODE *args, uint8_t *canceled);
