@@ -1,6 +1,6 @@
 /***************************************************************************
     begin       : Tue Dec 31 2013
-    copyright   : (C) 2018 by Martin Preuss
+    copyright   : (C) 2022 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -21,18 +21,10 @@ struct AH_JOB_TRANSFERBASE {
   AB_TRANSACTION_TYPE transactionType;
   AB_TRANSACTION_SUBTYPE transactionSubType;
   char *fiid;
+  char *descriptor;
+  char *profileName;
+  char *localInstrumentationCode;
 };
-static void GWENHYWFAR_CB AH_Job_TransferBase_FreeData(void *bp, void *p);
-
-static int AH_Job_TransferBase_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx);
-
-static int AH_Job_TransferBase_HandleResults(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx);
-
-/**
- * Set given status on all transfers and add copies of them to the given context.
- */
-static void AH_Job_TransferBase_SetStatusOnTransfersAndAddToCtx(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
-                                                                AB_TRANSACTION_STATUS status);
 
 
 #endif /* AH_JOBTRANSFERBASE_P_H */
