@@ -487,9 +487,7 @@ int _sendAndRecvCustomerBoxes(AH_OUTBOX *ob)
 {
   AH_OUTBOX_CBOX *cbox;
   int rv;
-  int errors;
 
-  errors=0;
   while ((cbox=AH_OutboxCBox_List_First(ob->userBoxes))) {
     AB_USER *u;
 
@@ -500,8 +498,6 @@ int _sendAndRecvCustomerBoxes(AH_OUTBOX *ob)
     _finishCBox(ob, cbox);
     AH_OutboxCBox_List_Del(cbox);
     AH_OutboxCBox_free(cbox);
-    if (rv)
-      errors++;
     if (rv==GWEN_ERROR_USER_ABORTED) {
       _finishRemainingCustomerBoxes(ob);
       return rv;
@@ -539,12 +535,12 @@ unsigned int _countTodoJobs(AH_OUTBOX *ob)
           AH_JOB *j;
 
           j=AH_Job_List_First(jl);
-	  while (j) {
-	    if (!(AH_Job_GetFlags(j) & AH_JOB_FLAGS_OUTBOX))
-	      cnt++;
+          while (j) {
+            if (!(AH_Job_GetFlags(j) & AH_JOB_FLAGS_OUTBOX))
+              cnt++;
 
-	    j=AH_Job_List_Next(j);
-	  } /* while */
+            j=AH_Job_List_Next(j);
+          } /* while */
         }
       }
       jq=AH_JobQueue_List_Next(jq);
