@@ -541,6 +541,18 @@ void AH_Job_SubFlags(AH_JOB *j, uint32_t f)
 
 
 
+void AH_Job_LogFlags(const AH_JOB *j, const char *msg)
+{
+  GWEN_BUFFER *bufFlags;
+
+  bufFlags=GWEN_Buffer_new(0, 128, 0, 1);
+  _flagsToBuffer(j->flags, bufFlags);
+  DBG_INFO(AQHBCI_LOGDOMAIN, "%s [job \"%s\", flags %08x: %s]", msg?msg:"", j->name, j->flags, GWEN_Buffer_GetStart(bufFlags));
+  GWEN_Buffer_free(bufFlags);
+}
+
+
+
 GWEN_DB_NODE *AH_Job_GetParams(const AH_JOB *j)
 {
   assert(j);
@@ -1649,10 +1661,10 @@ char *AH_Job_GenerateIdFromDateTimeAndJobId(const AH_JOB *j, int runningNumber)
   GWEN_Time_GetBrokenDownTime(ti, &hours, &mins, &secs);
   GWEN_Time_free(ti);
 
-  string31=(char*) malloc(31);
+  string31=(char *) malloc(31);
   /* YYYYMMDDhhmmssJJJJJJJJRRRRRRRR */
   rv=snprintf(string31, 31, "%04d%02d%02d%02d%02d%02d%08x%08x",
-	      year, month+1, days, hours, mins, secs, j->id, runningNumber);
+              year, month+1, days, hours, mins, secs, j->id, runningNumber);
   if (rv<0 || rv>30) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "Error on snprintf (%d)", rv);
     free(string31);
