@@ -31,13 +31,11 @@ struct AH_JOBQUEUE {
 
   char *usedTan;
   char *usedPin; /* used for checking bad pins in AH_JobQueue_DispatchMessage */
+
+  AH_JOBQUEUE *referenceQueue;
 };
 
 
-static void AH_JobQueue_SetUsedTan(AH_JOBQUEUE *jq, const char *s);
-static void AH_JobQueue_SetUsedPin(AH_JOBQUEUE *jq, const char *s);
-static int AH_JobQueue__CheckTans(AH_JOBQUEUE *jq, uint32_t guiid);
-
 
 #endif /* AH_JOBQUEUE_P_H */
 
